@@ -2,7 +2,7 @@
 #define oxygenmenubarstatedata_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * MenuBarState prelight effect is based on
@@ -36,6 +36,8 @@
 
 #include <gtk/gtk.h>
 
+#include <map>
+
 namespace Oxygen
 {
     class MenuBarStateData: public FollowMouseData
@@ -55,10 +57,12 @@ namespace Oxygen
         { disconnect( _target ); }
 
         //! setup connections
-        void connect( GtkWidget* );
+        using FollowMouseData::connect;
+        virtual void connect( GtkWidget* );
 
         //! disconnect
-        void disconnect( GtkWidget* );
+        using FollowMouseData::disconnect;
+        virtual void disconnect( GtkWidget* );
 
         //! enable state
         void setAnimationsEnabled( bool value )
@@ -118,6 +122,12 @@ namespace Oxygen
 
         protected:
 
+        //! register child
+        void registerChild( GtkWidget* );
+
+        //! disconnect child
+        void unregisterChild( GtkWidget* );
+
         //! update items
         void updateItems( GdkEventType );
 
@@ -206,6 +216,9 @@ namespace Oxygen
         //!@name callbacks
         //@{
 
+        //! child is destroyed
+        static gboolean childDestroyNotifyEvent( GtkWidget*, gpointer );
+
         //! mouse motion events
         static gboolean motionNotifyEvent( GtkWidget*, GdkEventMotion*, gpointer);
 
@@ -245,6 +258,10 @@ namespace Oxygen
 
         //@}
 
+        //! map children to destroy signal
+        typedef std::map<GtkWidget*, Signal> ChildrenMap;
+        ChildrenMap _children;
+
     };
 
 }
