@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * GdkPixbuf modification code from Walmis
@@ -404,7 +404,15 @@ namespace Oxygen
     }
 
     //________________________________________________________
-    bool Gtk::gtk_combobox_is_viewport( GtkWidget* widget )
+    bool Gtk::gtk_combobox_is_popup( GtkWidget* widget )
+    {
+        // check types and path
+        if( !GTK_IS_WINDOW(widget) ) return false;
+        return Gtk::gtk_widget_path( widget ) == "gtk-combobox-popup-window";
+    }
+
+    //________________________________________________________
+    bool Gtk::gtk_combo_is_viewport( GtkWidget* widget )
     {
         if( !GTK_IS_VIEWPORT(widget) ) return false;
         static const std::string match( "gtk-combo-popup-window" );
@@ -412,13 +420,21 @@ namespace Oxygen
     }
 
     //________________________________________________________
-    bool Gtk::gtk_combobox_is_frame( GtkWidget* widget )
+    bool Gtk::gtk_combo_is_frame( GtkWidget* widget )
     {
         if( !GTK_IS_FRAME(widget) ) return false;
         static const std::string match( "gtk-combo-popup-window" );
         return Gtk::gtk_widget_path( widget ).substr( 0, match.size() ) == match;
     }
 
+    //________________________________________________________
+    bool Gtk::gtk_combo_is_popup( GtkWidget* widget )
+    {
+        if( !GTK_IS_WINDOW(widget) ) return false;
+        static const std::string match( "gtk-combo-popup-window" );
+        return Gtk::gtk_widget_path( widget ) == match;
+    }
+
     //________________________________________________________
     bool Gtk::gtk_combobox_appears_as_list( GtkWidget* widget )
     {
@@ -427,6 +443,14 @@ namespace Oxygen
         return (bool) appearsAsList;
     }
 
+    //________________________________________________________
+    bool Gtk::gtk_is_tooltip( GtkWidget* widget )
+    {
+        if( GTK_IS_TOOLTIP(widget) ) return true;
+        const std::string path(Gtk::gtk_widget_path( widget ));
+        return  path == "gtk-tooltip" || path == "gtk-tooltips";
+    }
+
     //________________________________________________________
     bool Gtk::gtk_notebook_tab_contains( GtkWidget* widget, int tab, int x, int y )
     {
